==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Projection/IsometricProjection/IsoProject/ts/IsoProject_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>IsoProject</name>
    <message>
        <location filename="../IsoProject.ui" line="+17"/>
        <source>Top</source>
        <translation>Boven</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Bottom</source>
        <translation>Onderkant</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Left back</source>
        <translation>Links achter</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Right back</source>
        <translation>Rechts achter</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Rotate selection counter-clockwise before projection</source>
        <translation>Draai selectie tegen de klok voor projectie</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Rotate selection clockwise before projection</source>
        <translation>Draai selectie met de klok voor projectie</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Scale projection to original size (&apos;isometric drawing&apos;)</source>
        <translation>Schaal projectie op oorspronkelijke grootte (&quot;isometrische tekening&quot;)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>True scale</source>
        <translation>Ware grootte</translation>
    </message>
    <message>
        <location filename="../IsoProjectInit.js" line="+2"/>
        <source>&amp;Isometric Projection</source>
        <translation>&amp;Isometrische projectie</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Projection/IsometricProjection/IsoProject/ts/IsoProject_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>IsoProject</name>
    <message>
        <location filename="../IsoProject.ui" line="+17"/>
        <source>Top</source>
        <translation>Boven</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Bottom</source>
        <translation>Onderkant</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Left back</source>
        <translation>Links achter</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Right back</source>
        <translation>Rechts achter</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Rotate selection counter-clockwise before projection</source>
        <translation>Draai selectie tegen de klok voor projectie</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Rotate selection clockwise before projection</source>
        <translation>Draai selectie met de klok voor projectie</translation>
    </message>
    <message>
        <source>Scale projection to original size (&apos;isometric drawing&apos;)</source>
        <translation type="vanished">Schaal projectie op oorspronkelijke grootte (&quot;isometrische tekening&quot;)</translation>
    </message>
    <message>
        <source>True scale</source>
        <translation type="vanished">Ware grootte</translation>
    </message>
    <message>
        <location filename="../IsoProjectInit.js" line="+2"/>
        <source>&amp;Isometric Projection</source>
        <translation>&amp;Isometrische projectie</translation>
    </message>
    <message>
        <location filename="../IsoProject.js" line="+50"/>
        <source>Isometric</source>
        <translation>Isometrisch</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Isometric True Scale</source>
        <translation>Isometrisch ware grootte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Planometric</source>
        <translation>Planometric</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimetric</source>
        <translation>Dimetric</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Cabinet</source>
        <translation>Kabinet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cavalier</source>
        <translation>Cavalier</translation>
    </message>
</context>
</TS>
